| treeSS-package | R Documentation |
Implements the tree-spatial scan statistic for detecting clusters that combine both spatial and hierarchical structures, as proposed by Cançado et al. (2025). The method extends Kulldorff's (1997) circular spatial scan statistic and the tree-based scan statistic (Kulldorff et al. 2003) by searching for anomalies in both geographic regions and branches of hierarchical trees simultaneously.
treespatial_scanPerforms the tree-spatial scan statistic, detecting clusters defined by pairs of spatial zones and tree branches.
circular_scanPerforms Kulldorff's circular spatial scan statistic.
tree_scanPerforms the tree-based scan statistic.
build_zonesConstructs candidate spatial zones using circular windows centered on region centroids.
aggregate_treeAggregates case counts from leaves to internal nodes of the hierarchical tree.
filter_clustersRemoves overlapping secondary clusters from the tree-spatial scan output.
Maintainer: Allan Quadros allanvcq@gmail.com (ORCID)
Authors:
Andre L. F. Cancado (ORCID)
Geiziane S. Oliveira
Luiz H. Duczmal
Cançado, A. L. F., Oliveira, G. S., Quadros, A. V. C., & Duczmal, L. (2025). A tree-spatial scan statistic. Environmental and Ecological Statistics, 32, 953–978. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s10651-025-00670-w")}
Kulldorff, M. (1997). A spatial scan statistic. Communications in Statistics - Theory and Methods, 26(6), 1481–1496.
Kulldorff, M., Fang, Z., & Walsh, S. J. (2003). A tree-based scan statistic for database disease surveillance. Biometrics, 59(2), 323–331.
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.